@@ -9,11 +9,11 @@ class Registro(BaseModel, ABC):
     def ler_registro(cls, linha: str):
         valores = linha.split("|")[1:-1]
 
-        # Os campos iniciados com registros_ são filhos do registro
-
+        # Todos os atributos da classe
         campos = list(cls.__fields__.keys())
 
-        # Se existem
+        # Exclui os atributos com exclude=True
+        # Geralmente os filhos
         if cls.__exclude_fields__:
             campos = [
                 campo for campo in campos if campo not in cls.__exclude_fields__]
@@ -30,6 +30,9 @@ class Registro(BaseModel, ABC):
         except ValorCampoInvalido as e:
             raise LinhaRegistroInvalida(f'Linha invalida.\n{linha}\n{e}')
 
+    def __str__(self) -> str:
+        return super().__str__()
+
 
 class Bloco(BaseModel, ABC):
 
